package com.hzya.frame.plugin.SendContract.plugin;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.SendContract.dao.ISendContractDao;
import com.hzya.frame.plugin.SendContract.entity.SendContractEntity;
import com.hzya.frame.plugin.SendContract.service.ISendContractService;
import com.hzya.frame.sysnew.comparison.serviceData.service.IServiceDataService;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.uuid.UUIDUtils;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.bson.json.JsonObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.Date;
import java.util.List;

/**
 * 未定合同号
 *
 * @author makejava
 * @since 2024-06-21 13:52:35
 */
public class SendContractPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(SendContractPluginInitializer.class);
    @Autowired
    private ISendContractDao sendContractDao;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;
    @Value("${zt.url}")
    private String url;
    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "SendContractPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "业务数据抽取";
    }

    @Override
    public String getPluginLabel() {
        return "SendContractPluginInitializer";
    }

    @Override
    public String getPluginType() {
        return "1";
    }

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) {
        try {
            logger.info("======开始执行OA合同数据信息同步========");
            //重试方法
            if (null != requestJson) {
                //如果这个id不为空，说明是重试的
                String id = requestJson.getString("integration_task_living_details_id");
                //执行重新发送
                SendContractEntity sendContractEntity = new SendContractEntity();
                sendContractEntity.setDataSourceCode("SW-OA");
                if (StrUtil.isNotEmpty(id)) {
                    sendContractEntity.setId(id);
                }
                //查询数据
                List<SendContractEntity> sendContractEntityList = sendContractDao.querySend(sendContractEntity);
                if(sendContractEntityList == null || sendContractEntityList.size() == 0){
                    return BaseResult.getSuccessMessageEntity("执行成功");
                }
                for (int i = 0; i < sendContractEntityList.size(); i++) {
                    //组装数据
                    JSONObject sendData = getSendData(sendContractEntityList.get(i));
                    JSONObject tokenData = getBipTokenData();
                    SendContractEntity updatedata = new SendContractEntity();
                    updatedata.setDataSourceCode("SW-OA");
                    updatedata.setId(sendContractEntityList.get(i).getId());
                    //获取TOKEN
                    String tokenResult = HttpRequest.post(url).
                            header("appId", "800050").
                            header("apiCode", "8000500003").
                            header("publicKey", "ZJYAM2YFEIsIaI1e4wMagkS2Q7SFgGk0RvsPhEES45m/OVFCe7eDIk+3zDUT+v578prj").
                            header("secretKey", "lR6+uf94mvNMclAB43oIwmhJSMDzQaViTkfXLeNvmGdpLfbFiUvbgbU+p43zO25Zj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(tokenData.toString()).
                            execute().
                            body();
                    logger.error("合同BIPtoken返回："+tokenResult);
                    JSONObject tokenResultJson = JSONObject.parseObject(tokenResult);
                    if(!tokenResultJson.getBoolean("flag")){
                        updatedata.setStatus("0");
                        updatedata.setMsg("执行失败，Token获取失败");
                        sendContractDao.updateData(updatedata);
                        continue;
                    }
                    String tokenBody = tokenResultJson.getJSONObject("attribute").getJSONObject("data").getString("access_token");
                    //发送数据
                    String result = HttpRequest.post(url).
                            header("appId", "800050").
                            header("apiCode", "8000500010").
                            header("access_token", tokenBody).
                            header("publicKey", "ZJYAM2YFEIsIaI1e4wMagkS2Q7SFgGk0RvsPhEES45m/OVFCe7eDIk+3zDUT+v578prj").
                            header("secretKey", "lR6+uf94mvNMclAB43oIwmhJSMDzQaViTkfXLeNvmGdpLfbFiUvbgbU+p43zO25Zj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(sendData.toString()).
                            execute().
                            body();
                    JSONObject resultJson = JSONObject.parseObject(result);
                    if(!resultJson.getBoolean("flag")){
                        updatedata.setStatus("0");
                        updatedata.setMsg("发送失败"+resultJson.getString("msg"));
                        sendContractDao.updateData(updatedata);
                        saveTaskLivingDetails(sendContractEntityList.get(i).getId(),sendContractEntityList.get(i).getId(),sendContractEntityList.get(i).getId(),tokenBody,false);
                    }else {
                        updatedata.setStatus("1");
                        updatedata.setMsg("发送成功");
                        sendContractDao.updateData(updatedata);
                        saveTaskLivingDetails(sendContractEntityList.get(i).getId(),sendContractEntityList.get(i).getId(),sendContractEntityList.get(i).getId(),tokenBody,true);
                    }
                }
            }
            logger.info("执行成功");
            return BaseResult.getSuccessMessageEntity("执行成功");
        } catch (Exception e) {
            logger.info("======执行OA合同数据同步失败:{}========", e.getMessage());
            e.printStackTrace();
        }
        return BaseResult.getFailureMessageEntity("执行失败");
    }

    private JSONObject getBipTokenData() {
        JSONObject jsonObject = new JSONObject();



        return jsonObject;
    }

    /**
     * @Author lvleigang
     * @Description  组装数据
     * @Date 2:21 下午 2025/1/6
     * @param sendContractEntity
     * @return com.alibaba.fastjson.JSONObject
     **/
    private JSONObject getSendData(SendContractEntity sendContractEntity) {
        JSONObject jsonObject = new JSONObject();
        JSONObject ufinterface = new JSONObject();
        JSONObject bill = new JSONObject();
        JSONObject billhead = new JSONObject();
        ufinterface.put("account","SW01");
        ufinterface.put("billtype","project");
        ufinterface.put("groupcode","SW01");
        ufinterface.put("isexchange","Y");
        ufinterface.put("replace","Y");
        ufinterface.put("sender","default");
        ufinterface.put("id",sendContractEntity.getId());
        ufinterface.put("pk_defdoclist","HHWDH");

        billhead.put("filesource","1");
        if(sendContractEntity.getCjr() != null && !"".equals(sendContractEntity.getCjr())){
            billhead.put("creator",sendContractEntity.getCjr());
        }else {
            billhead.put("creator","OA01");
        }
        billhead.put("transi_type","4D10-01");
        billhead.put("bill_type","4D10");
        billhead.put("pk_eps","0202");
        billhead.put("pk_group","SW01");
        billhead.put("pk_org","666");
        billhead.put("project_code",sendContractEntity.getProjectCode());
        //billhead.put("project_name",sendContractEntity.getProjectName());
        //2025年6月6日17:46:45 相二林修改， 三维通信BIP-致远OA接口群 胡飞洲让改的
        billhead.put("project_name",sendContractEntity.getProjectCode());
        billhead.put("def1",sendContractEntity.getKhcode());//BIP客户编码
        bill.put("billhead",billhead);
        ufinterface.put("bill",bill);
        jsonObject.put("ufinterface",ufinterface);
        return jsonObject;
    }


    private void saveTaskLivingDetails(String rootAppPk,String rootAppBill,String rootAppNewData,String newTransmitInfo,boolean flag) {
        try {
            IntegrationTaskLivingDetailsEntity integrationTaskLivingDetailsEntity = new IntegrationTaskLivingDetailsEntity();
            integrationTaskLivingDetailsEntity.setId(UUIDUtils.getUUID());
            integrationTaskLivingDetailsEntity.setSts("Y");
            integrationTaskLivingDetailsEntity.setCreate_user_id("1");
            integrationTaskLivingDetailsEntity.setModify_user_id("1");
            integrationTaskLivingDetailsEntity.setCreate_time(new Date());
            integrationTaskLivingDetailsEntity.setModify_time(new Date());
            integrationTaskLivingDetailsEntity.setOrg_id("0");
            integrationTaskLivingDetailsEntity.setCompanyId("0");
            integrationTaskLivingDetailsEntity.setRootAppPk(rootAppPk);
            integrationTaskLivingDetailsEntity.setRootAppBill(rootAppBill);
            integrationTaskLivingDetailsEntity.setPluginId("SendContractPluginInitializer");
            integrationTaskLivingDetailsEntity.setRootAppNewData(rootAppNewData);
            integrationTaskLivingDetailsEntity.setNewTransmitInfo(newTransmitInfo);
            if(flag){
                taskLivingDetailsService.saveLogToSuccess(integrationTaskLivingDetailsEntity);
            }else {
                taskLivingDetailsService.saveLogToFail(integrationTaskLivingDetailsEntity);
            }
        }catch (Exception e){
            logger.info("保存日志到集成任务日志明细中失败:{}",e.getMessage());
        }
    }
}
