package com.hzya.frame.plugin.c4project.plugin;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.c4project.dao.IC4ProjectDao;
import com.hzya.frame.plugin.c4project.dao.impl.C4ProjectDaoImpl;
import com.hzya.frame.plugin.c4project.entity.C4ProjectEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.uuid.UUIDUtils;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;

public class C4ProjectPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(C4ProjectPluginInitializer.class);

    @Autowired
    private IC4ProjectDao ic4ProjectDao;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "C4ProjectPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "研发项目立项生成C4项目档案";
    }

    @Override
    public String getPluginLabel() {
        return "C4ProjectPluginInitializer";
    }

    @Override
    public String getPluginType() {
        return "1";
    }

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        try {
            String startTime = DateUtil.format(requestJson.getDate("startTime"),"yyyy-MM-dd HH:mm:ss");//定时任务执行时传入的开始时间
            String endTime = DateUtil.format(requestJson.getDate("endTime"),"yyyy-MM-dd HH:mm:ss");//定时任务执行时传入的开始时间
            logger.info("=======研发项目立项推送C4项目档案的开始时间为：{}=======",startTime);
            logger.info("=======研发项目立项推送C4项目档案的结束时间为：{}=======",endTime);
           if(StrUtil.isEmpty(startTime)){
               DateUtil.format(new Date(),"yyyy-MM-dd HH:mm:ss");
           }

           logger.info("=======在:{}时间查询研发项目立项推送C4项目档案=======",startTime);
            C4ProjectEntity c4ProjectEntity=new C4ProjectEntity();
           c4ProjectEntity.setStartTime(startTime);
           c4ProjectEntity.setDataSourceCode("SW-OA");
            List<C4ProjectEntity> c4ProjectEntities = ic4ProjectDao.queryProjectToC4(c4ProjectEntity);
            if(c4ProjectEntities == null || c4ProjectEntities.size() == 0){
                logger.info("=====查询研发项目立项推送C4项目档案数据有:{}条",c4ProjectEntities.size());
                return BaseResult.getSuccessMessageEntity("查询成功");
            }
            for (C4ProjectEntity projectEntity : c4ProjectEntities) {
                projectEntity.setDataSourceCode("SW-OA");
                projectEntity.setCaFulllevelno("@"+projectEntity.getCaNo()+"@");
                projectEntity.setCaTypenm(projectEntity.getCaTypenm()==null?"项目类型":projectEntity.getCaTypenm());
                logger.info("======开始将项目编号：{}，项目名称：{}新增到C4项目档案中=======",projectEntity.getCaNo(),projectEntity.getCaName());
                Integer integer = ic4ProjectDao.saveC4Project(projectEntity);
                logger.info("======将项目编号：{}，项目名称：{}新增到C4项目档案中完毕=======",projectEntity.getCaNo(),projectEntity.getCaName());
                saveTaskLivingDetails(projectEntity.getId(),projectEntity.getCaNo(),JSONObject.parseObject(projectEntity.toString()).toJSONString(),String.valueOf(integer),true);
            }
            logger.info("=======研发项目立项推送C4项目档案执行成功=======");
            return BaseResult.getSuccessMessageEntity("研发项目立项推送C4项目档案执行成功");
        }catch (Exception e){
            logger.info("========研发项目立项推送C4项目档案失败,:{}",e.getMessage());
            e.printStackTrace();
        }
        return BaseResult.getFailureMessageEntity("研发项目立项推送C4项目档案执行成功");
    }

    private void saveTaskLivingDetails(String rootAppPk,String rootAppBill,String rootAppNewData,String newTransmitInfo,boolean flag) {
        try {
            IntegrationTaskLivingDetailsEntity integrationTaskLivingDetailsEntity = new IntegrationTaskLivingDetailsEntity();
            integrationTaskLivingDetailsEntity.setId(UUIDUtils.getUUID());
            integrationTaskLivingDetailsEntity.setSts("Y");
            integrationTaskLivingDetailsEntity.setCreate_user_id("1");
            integrationTaskLivingDetailsEntity.setModify_user_id("1");
            integrationTaskLivingDetailsEntity.setCreate_time(new Date());
            integrationTaskLivingDetailsEntity.setModify_time(new Date());
            integrationTaskLivingDetailsEntity.setOrg_id("0");
            integrationTaskLivingDetailsEntity.setCompanyId("0");
            integrationTaskLivingDetailsEntity.setRootAppPk(rootAppPk);
            integrationTaskLivingDetailsEntity.setRootAppBill(rootAppBill);
            integrationTaskLivingDetailsEntity.setPluginId("C4ProjectPluginInitializer");
            integrationTaskLivingDetailsEntity.setRootAppNewData(rootAppNewData);
            integrationTaskLivingDetailsEntity.setNewTransmitInfo(newTransmitInfo);
            if(flag){
                taskLivingDetailsService.saveLogToSuccess(integrationTaskLivingDetailsEntity);
            }else {
                taskLivingDetailsService.saveLogToFail(integrationTaskLivingDetailsEntity);
            }
        }catch (Exception e){
            logger.info("保存日志到集成任务日志明细中失败:{}",e.getMessage());
        }
    }
}
