package com.hzya.frame.plugin.projectMainFlow.plugin;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.SendContract.entity.SendContractEntity;
import com.hzya.frame.plugin.projectMainFlow.dao.IProjectMainFlowDao;
import com.hzya.frame.plugin.projectMainFlow.entity.ProjectMainFlowEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.uuid.UUIDUtils;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.Date;
import java.util.List;

public class ProjectMainFlowArchivistPluginInitializer extends PluginBaseEntity {

    Logger logger = LoggerFactory.getLogger(ProjectMainFlowArchivistPluginInitializer.class);

    @Autowired
    private IProjectMainFlowDao projectMainFlowDao;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;

    @Value("${zt.url}")
    private String url;

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "ProjectMainFlowArchivistPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "项目主流程审定";
    }

    @Override
    public String getPluginLabel() {
        return "ProjectMainFlowArchivistPluginInitializer";
    }

    @Override
    public String getPluginType() {
        return "1";
    }

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson)  {
        try {
            logger.info("======开始执行项目主流程归档推送BIP========");
            //重试方法
            if (null != requestJson) {
                //如果这个id不为空，说明是重试的
                String id = requestJson.getString("integration_task_living_details_id");
                //执行重新发送
                ProjectMainFlowEntity projectMainFlowEntity = new ProjectMainFlowEntity();
                projectMainFlowEntity.setDataSourceCode("SW-OA");
                if (StrUtil.isNotEmpty(id)) {
                    projectMainFlowEntity.setId(id);
                }
                //查询审定之后数据
                List<ProjectMainFlowEntity> projectMainFlowEntities = projectMainFlowDao.queryProjectMainFlowArchivist(projectMainFlowEntity);
                if(projectMainFlowEntities == null || projectMainFlowEntities.size() == 0){
                    logger.info("=====查询项目主流程归档数据有:{}条",projectMainFlowEntities.size());
                    return BaseResult.getSuccessMessageEntity("查询成功");
                }
                for (ProjectMainFlowEntity mainFlowEntity : projectMainFlowEntities) {
                    //组装数据
                    JSONObject sendData = getSendData(mainFlowEntity);
                    JSONObject tokenData = getBipTokenData();
                    mainFlowEntity.setDataSourceCode("SW-OA");
                    //获取TOKEN
                    String tokenResult = HttpRequest.post(url).
                            header("appId", "800050").
                            header("apiCode", "8000500003").
                            header("publicKey", "ZJYAQ/VtQ66PqKXlV0EowrrlKkhBHYgS/Zk39Q5ezIQne51Ce7eDIk+3zDUT+v578prj").
                            header("secretKey", "iLLk424Bmzknbu+ROeJoiVDMYY5EFXtbZY/aU13HmVYIiQrIw9c0Ag4ipxbfpUqqj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(tokenData.toString()).
                            execute().
                            body();
                    logger.error("项目主流程归档BIPtoken返回结果："+tokenResult);
                    JSONObject tokenResultJson = JSONObject.parseObject(tokenResult);
                    if(!tokenResultJson.getBoolean("flag")){
                        mainFlowEntity.setArchivistStatus("0");
                        mainFlowEntity.setArchivistResult("执行失败，Token获取失败");
                        projectMainFlowDao.updateProjectMainFlow(mainFlowEntity);
                        continue;
                    }
                    String tokenBody = tokenResultJson.getJSONObject("attribute").getJSONObject("data").getString("access_token");
                    //发送数据
                    String result = HttpRequest.post(url).
                            header("appId", "800050").
                            header("apiCode", "8000500011").
                            header("access_token", tokenBody).
                            header("publicKey", "ZJYAQ/VtQ66PqKXlV0EowrrlKkhBHYgS/Zk39Q5ezIQne51Ce7eDIk+3zDUT+v578prj").
                            header("secretKey", "iLLk424Bmzknbu+ROeJoiVDMYY5EFXtbZY/aU13HmVYIiQrIw9c0Ag4ipxbfpUqqj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(sendData.toString()).
                            execute().
                            body();
                    logger.error("项目主流程归档之后返回结果："+result);
                    JSONObject resultJson = JSONObject.parseObject(result);
                    if(!resultJson.getBoolean("flag")){
                        mainFlowEntity.setArchivistStatus("0");
                        mainFlowEntity.setArchivistResult("归档发送失败"+resultJson.getString("msg"));
                        projectMainFlowDao.updateProjectMainFlow(mainFlowEntity);
                        saveTaskLivingDetails(mainFlowEntity.getId(),mainFlowEntity.getId(),sendData.toString(),resultJson.toJSONString(),false);
                    }else {
                        mainFlowEntity.setArchivistStatus("1");
                        mainFlowEntity.setArchivistResult("归档发送成功");
                        projectMainFlowDao.updateProjectMainFlow(mainFlowEntity);
                        saveTaskLivingDetails(mainFlowEntity.getId(),mainFlowEntity.getId(),sendData.toString(),resultJson.toJSONString(),true);
                    }
                }
            }
            logger.info("=======项目主流程归档推送BIP执行成功=======");
            return BaseResult.getSuccessMessageEntity("项目主流程归档执行成功");
        } catch (Exception e) {
            logger.info("======执行项目主流程归档推送BIP失败:{}========", e.getMessage());
            e.printStackTrace();
        }
        return BaseResult.getFailureMessageEntity("项目主流程归档执行失败");
    }


    private JSONObject getBipTokenData() {
        JSONObject jsonObject = new JSONObject();



        return jsonObject;
    }


    private JSONObject getSendData(ProjectMainFlowEntity projectMainFlowEntity) {
        JSONObject htdd01Master = new JSONObject();
        JSONObject bill = new JSONObject();
        JSONObject htdd01slave4_htdd01slave4 = new JSONObject();
        JSONArray jsonArray=new JSONArray();
        htdd01Master.put("pk_group",projectMainFlowEntity.getPkGroup());
        htdd01Master.put("pk_org",projectMainFlowEntity.getPkOrg());
        htdd01Master.put("contractno",projectMainFlowEntity.getContractno());
        htdd01Master.put("name",projectMainFlowEntity.getContractname());
       // htdd01Master.put("creator",projectMainFlowEntity.getCreator());
      //  htdd01Master.put("creationtime",projectMainFlowEntity.getCreationtime());

        htdd01slave4_htdd01slave4.put("contractno",projectMainFlowEntity.getContractno());
        htdd01slave4_htdd01slave4.put("projectno",projectMainFlowEntity.getProjectno());
        htdd01slave4_htdd01slave4.put("completemoney",projectMainFlowEntity.getCompletemoney());
        htdd01slave4_htdd01slave4.put("completedate",projectMainFlowEntity.getCompletedate());
        htdd01slave4_htdd01slave4.put("completepersion",projectMainFlowEntity.getCompletepersion());
        htdd01slave4_htdd01slave4.put("pinspectionmoney",projectMainFlowEntity.getPinspectionmoney());
        htdd01slave4_htdd01slave4.put("pinspectiondate",projectMainFlowEntity.getPinspectiondate());
        htdd01slave4_htdd01slave4.put("pinspectionpersion",projectMainFlowEntity.getPinspectionpersion());
        htdd01slave4_htdd01slave4.put("auditmoney",projectMainFlowEntity.getAuditmoney());
        htdd01slave4_htdd01slave4.put("auditdate",projectMainFlowEntity.getAuditdate());
        htdd01slave4_htdd01slave4.put("auditpersion",projectMainFlowEntity.getAuditpersion());
        htdd01slave4_htdd01slave4.put("forecast_revenue",projectMainFlowEntity.getForecastRevenue());
        htdd01slave4_htdd01slave4.put("vnote",projectMainFlowEntity.getVnote());
        htdd01slave4_htdd01slave4.put("def1",projectMainFlowEntity.getDef1());
        htdd01slave4_htdd01slave4.put("def2",projectMainFlowEntity.getDef2());
        htdd01slave4_htdd01slave4.put("def3",projectMainFlowEntity.getDef3());
        htdd01slave4_htdd01slave4.put("def4",projectMainFlowEntity.getDef4());
        htdd01slave4_htdd01slave4.put("def5",projectMainFlowEntity.getDef5());
        htdd01slave4_htdd01slave4.put("def6",projectMainFlowEntity.getDef6());
        htdd01slave4_htdd01slave4.put("def7",projectMainFlowEntity.getDef7());
        htdd01slave4_htdd01slave4.put("def8",projectMainFlowEntity.getDef8());
        htdd01slave4_htdd01slave4.put("def9",projectMainFlowEntity.getDef9());
        htdd01slave4_htdd01slave4.put("def10",projectMainFlowEntity.getDef10());
        jsonArray.add(htdd01slave4_htdd01slave4);
        bill.put("htdd01Master",htdd01Master);
        bill.put("htdd01slave4_htdd01slave4",jsonArray);
        return bill;
    }


    private void saveTaskLivingDetails(String rootAppPk,String rootAppBill,String rootAppNewData,String newTransmitInfo,boolean flag) {
        try {
            IntegrationTaskLivingDetailsEntity integrationTaskLivingDetailsEntity = new IntegrationTaskLivingDetailsEntity();
            integrationTaskLivingDetailsEntity.setId(UUIDUtils.getUUID());
            integrationTaskLivingDetailsEntity.setSts("Y");
            integrationTaskLivingDetailsEntity.setCreate_user_id("1");
            integrationTaskLivingDetailsEntity.setModify_user_id("1");
            integrationTaskLivingDetailsEntity.setCreate_time(new Date());
            integrationTaskLivingDetailsEntity.setModify_time(new Date());
            integrationTaskLivingDetailsEntity.setOrg_id("0");
            integrationTaskLivingDetailsEntity.setCompanyId("0");
            integrationTaskLivingDetailsEntity.setRootAppPk(rootAppPk);
            integrationTaskLivingDetailsEntity.setRootAppBill(rootAppBill);
            integrationTaskLivingDetailsEntity.setPluginId("ProjectMainFlowArchivistPluginInitializer");
            integrationTaskLivingDetailsEntity.setRootAppNewData(rootAppNewData);
            integrationTaskLivingDetailsEntity.setNewTransmitInfo(newTransmitInfo);
            if(flag){
                taskLivingDetailsService.saveLogToSuccess(integrationTaskLivingDetailsEntity);
            }else {
                taskLivingDetailsService.saveLogToFail(integrationTaskLivingDetailsEntity);
            }
        }catch (Exception e){
            logger.info("保存日志到集成任务日志明细中失败:{}",e.getMessage());
        }
    }
}
