package com.hzya.frame.plugin.salesContract.plugin;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.projectMainFlow.entity.ProjectMainFlowEntity;
import com.hzya.frame.plugin.salesContract.dao.ISalesContractDao;
import com.hzya.frame.plugin.salesContract.entity.SalesContractEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.uuid.UUIDUtils;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.Date;
import java.util.List;

public class SalesContractPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(SalesContractPluginInitializer.class);

    @Autowired
    private ISalesContractDao salesContractDao;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;

    @Value("${zt.url}")
    private String url;

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "SalesContractPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "销售合同新增";
    }

    @Override
    public String getPluginLabel() {
        return "SalesContractPluginInitializer";
    }

    @Override
    public String getPluginType() {
        return "1";
    }

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson)  {
        try {
            logger.info("======开始执行销售合同推送BIP========");
            //重试方法
            if (null != requestJson) {
                //如果这个id不为空，说明是重试的
                String id = requestJson.getString("integration_task_living_details_id");
                //执行重新发送
                SalesContractEntity salesContractEntity = new SalesContractEntity();
                salesContractEntity.setDataSourceCode("SW-OA");
                if (StrUtil.isNotEmpty(id)) {
                    salesContractEntity.setId(id);
                }
                //查询未推送的数据
                List<SalesContractEntity> salesContractEntities = salesContractDao.querySalesContract(salesContractEntity);
                if(salesContractEntities == null || salesContractEntities.size() == 0){
                    logger.info("=====没有需要推送BIP的销售合同==========");
                    return BaseResult.getSuccessMessageEntity("查询成功");
                }
                for (SalesContractEntity contractEntity : salesContractEntities) {
                    //组装数据
                    JSONObject sendData = getSendData(contractEntity);
                    JSONObject tokenData = getBipTokenData();
                    contractEntity.setDataSourceCode("SW-OA");
                    //获取TOKEN
                    String tokenResult = HttpRequest.post(url).
                            header("appId", "800050").
                            header("apiCode", "8000500003").
                            header("publicKey", "ZJYAQ/VtQ66PqKXlV0EowrrlKkhBHYgS/Zk39Q5ezIQne51Ce7eDIk+3zDUT+v578prj").
                            header("secretKey", "iLLk424Bmzknbu+ROeJoiVDMYY5EFXtbZY/aU13HmVYIiQrIw9c0Ag4ipxbfpUqqj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(tokenData.toString()).
                            execute().
                            body();
                    logger.error("销售合同推送BIPtoken返回结果："+tokenResult);
                    JSONObject tokenResultJson = JSONObject.parseObject(tokenResult);
                    if(!tokenResultJson.getBoolean("flag")){
                        logger.info("=========销售合同获取biptoken错误，开始修改销售合同推送标识为失败==========");
                        contractEntity.setPushStatus("0");
                        salesContractDao.updateSalesContract(contractEntity);
                        logger.info("=========销售合同获取biptoken错误，修改销售合同推送标识完毕==========");
                        continue;
                    }
                    String tokenBody = tokenResultJson.getJSONObject("attribute").getJSONObject("data").getString("access_token");
                    logger.error("销售合同推送BIP请求参数："+sendData.toJSONString());
                    //发送数据
                    String result = HttpRequest.post(url).
                            header("appId", "800050").
                            header("apiCode", "8000500012").
                            header("access_token", tokenBody).
                            header("publicKey", "ZJYAQ/VtQ66PqKXlV0EowrrlKkhBHYgS/Zk39Q5ezIQne51Ce7eDIk+3zDUT+v578prj").
                            header("secretKey", "iLLk424Bmzknbu+ROeJoiVDMYY5EFXtbZY/aU13HmVYIiQrIw9c0Ag4ipxbfpUqqj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(sendData.toString()).
                            execute().
                            body();
                    logger.error("销售合同推送BIP返回结果："+result);
                    JSONObject resultJson = JSONObject.parseObject(result);
                    if(!resultJson.getBoolean("flag")){
                        logger.info("=========销售合同获取bip返回结果错误，开始修改销售合同推送标识为失败==========");
                        contractEntity.setPushStatus("0");
                        salesContractDao.updateSalesContract(contractEntity);
                        logger.info("=========销售合同获取bip返回结果错误，修改销售合同推送标识为失败完毕==========");
                        saveTaskLivingDetails(contractEntity.getId(),contractEntity.getContractno(),sendData.toString(),resultJson.toJSONString(),false);
                    }else {
                        logger.info("=========销售合同获取bip返回结果成功，开始修改销售合同推送标识为成功==========");
                        contractEntity.setPushStatus("1");
                        salesContractDao.updateSalesContract(contractEntity);
                        logger.info("=========销售合同获取bip返回结果成功，修改销售合同推送标识为成功完毕==========");
                        saveTaskLivingDetails(contractEntity.getId(),contractEntity.getContractno(),sendData.toString(),resultJson.toJSONString(),true);
                    }
                }
            }
            logger.info("=======销售合同推送BIP执行成功=======");
            return BaseResult.getSuccessMessageEntity("销售合同执行成功");
        }catch (Exception e){
            logger.info("======执行销售合同推送BIP失败:{}========", e.getMessage());
            e.printStackTrace();
        }
        return BaseResult.getFailureMessageEntity("销售合同执行失败");
    }

    private JSONObject getSendData(SalesContractEntity contractEntity) {
        JSONObject bill = new JSONObject();
        bill.put("pk_group",contractEntity.getPkGroup());//集团编码
        bill.put("pk_org",contractEntity.getPkOrg());//公司编码
        bill.put("contractno",contractEntity.getContractno());//合同号
        bill.put("name",contractEntity.getContractName());//合同名称
        bill.put("creator",contractEntity.getCreator());//创建人用户
        bill.put("creationtime",contractEntity.getCreationtime());//创建时间
        bill.put("billdate",contractEntity.getBilldate());//申请日期
        bill.put("contractor",contractEntity.getContractor());//订单负责人名称
        bill.put("cdeptid",contractEntity.getCdeptid());//事业部
        bill.put("approvestatus",contractEntity.getApprovestatus());//审批状态默认
        bill.put("belongtodeptid",contractEntity.getBelongtodeptid());//单据归属部门
        bill.put("dpk_custclass",contractEntity.getDpk_custclass());//合同对应客户大类
        bill.put("dcustomerid",contractEntity.getDcustomerid());//合同对应客户大类
        bill.put("zcustomerid",contractEntity.getZcustomerid());
        bill.put("cinvoicecustid",contractEntity.getCinvoicecustid());//开票客户名称
        bill.put("cemployeeid",contractEntity.getCemployeeid());//业务人员
        bill.put("ccurrencyid",contractEntity.getCcurrencyid());//币种
        bill.put("totalamount",contractEntity.getTotalamount());//原币总金额
        bill.put("rmbtotalamount",contractEntity.getRmbtotalamount());//人民币总金额
        bill.put("presentrate",contractEntity.getPresentrate());//汇率
        bill.put("def13",contractEntity.getDef13());//IPO合同号
        bill.put("def16",contractEntity.getDef16());//IPO汇率
        bill.put("def8",contractEntity.getDef8());//贸易方式
        bill.put("def27",contractEntity.getDef27());//IPO币种
        bill.put("def17",contractEntity.getDef17());//收款账期
        bill.put("def18",contractEntity.getDef18());//账簿本币金额
        bill.put("def26",contractEntity.getDef26());//当前账簿兑人民币汇率

        bill.put("custbillno",contractEntity.getCustbillno());//CPO订单编码
        bill.put("placementdate",contractEntity.getPlacementdate());//CPO下达日期
        bill.put("country",contractEntity.getCountry());//国家地区编码
        bill.put("vnote",contractEntity.getVnote());//备注
        bill.put("def9",contractEntity.getDef9());//合同类型
        bill.put("def2",contractEntity.getDef2());//合同性质
        bill.put("def41",contractEntity.getDef41());//单据归属区域
        JSONObject htdd01Master=new JSONObject();
        htdd01Master.put("htdd01Master",bill);
        return htdd01Master;
    }

    private JSONObject getBipTokenData() {
        JSONObject jsonObject = new JSONObject();



        return jsonObject;
    }


    private void saveTaskLivingDetails(String rootAppPk,String rootAppBill,String rootAppNewData,String newTransmitInfo,boolean flag) {
        try {
            IntegrationTaskLivingDetailsEntity integrationTaskLivingDetailsEntity = new IntegrationTaskLivingDetailsEntity();
            integrationTaskLivingDetailsEntity.setId(UUIDUtils.getUUID());
            integrationTaskLivingDetailsEntity.setSts("Y");
            integrationTaskLivingDetailsEntity.setCreate_user_id("1");
            integrationTaskLivingDetailsEntity.setModify_user_id("1");
            integrationTaskLivingDetailsEntity.setCreate_time(new Date());
            integrationTaskLivingDetailsEntity.setModify_time(new Date());
            integrationTaskLivingDetailsEntity.setOrg_id("0");
            integrationTaskLivingDetailsEntity.setCompanyId("0");
            integrationTaskLivingDetailsEntity.setRootAppPk(rootAppPk);
            integrationTaskLivingDetailsEntity.setRootAppBill(rootAppBill);
            integrationTaskLivingDetailsEntity.setPluginId("SalesContractPluginInitializer");
            integrationTaskLivingDetailsEntity.setRootAppNewData(rootAppNewData);
            integrationTaskLivingDetailsEntity.setNewTransmitInfo(newTransmitInfo);
            if (flag) {
                taskLivingDetailsService.saveLogToSuccess(integrationTaskLivingDetailsEntity);
            } else {
                taskLivingDetailsService.saveLogToFail(integrationTaskLivingDetailsEntity);
            }
        } catch (Exception e) {
            logger.info("保存日志到集成任务日志明细中失败:{}", e.getMessage());
        }
    }
}
